summaryrefslogtreecommitdiff
path: root/boost/math/special_functions/lambert_w.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'boost/math/special_functions/lambert_w.hpp')
-rw-r--r--boost/math/special_functions/lambert_w.hpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/boost/math/special_functions/lambert_w.hpp b/boost/math/special_functions/lambert_w.hpp
index 6b3dcebe2f..65d3be5f5c 100644
--- a/boost/math/special_functions/lambert_w.hpp
+++ b/boost/math/special_functions/lambert_w.hpp
@@ -61,7 +61,7 @@ BOOST_MATH_INSTRUMENT_LAMBERT_W_SMALL_Z_SERIES_ITERATIONS // Show evaluation of
#include <boost/mpl/int.hpp>
#include <boost/type_traits/is_integral.hpp>
#include <boost/math/tools/precision.hpp> // boost::math::tools::max_value().
-#include <boost/math/tools/test_value.hpp> // For create_test_value and macro BOOST_MATH_TEST_VALUE.
+#include <boost/math/tools/big_constant.hpp>
#include <limits>
#include <cmath>
@@ -296,27 +296,27 @@ T lambert_w_singularity_series(const T p)
// -T(0.000672061631156136204L), j14
//+T(1003663334225097487uLL) / 234281684403486720000uLL, // j15 0.00044247306181462090993020760858473726479232802068800 error C2177: constant too big
//+T(0.000442473061814620910L, // j15
- BOOST_MATH_TEST_VALUE(T, +0.000442473061814620910), // j15
+ BOOST_MATH_BIG_CONSTANT(T, 64, +0.000442473061814620910), // j15
// -T(0.000292677224729627445L), // j16
- BOOST_MATH_TEST_VALUE(T, -0.000292677224729627445), // j16
+ BOOST_MATH_BIG_CONSTANT(T, 64, -0.000292677224729627445), // j16
//+T(0.000194387276054539318L), // j17
- BOOST_MATH_TEST_VALUE(T, 0.000194387276054539318), // j17
+ BOOST_MATH_BIG_CONSTANT(T, 64, 0.000194387276054539318), // j17
//-T(0.000129574266852748819L), // j18
- BOOST_MATH_TEST_VALUE(T, -0.000129574266852748819), // j18
+ BOOST_MATH_BIG_CONSTANT(T, 64, -0.000129574266852748819), // j18
//+T(0.0000866503580520812717L), // j19 N[+1150497127780071399782389/13277465363600276402995200000, 50] 0.000086650358052081271660451590462390293190597827783288
- BOOST_MATH_TEST_VALUE(T, +0.0000866503580520812717), // j19
+ BOOST_MATH_BIG_CONSTANT(T, 64, +0.0000866503580520812717), // j19
//-T(0.0000581136075044138168L) // j20 N[2853534237182741069/49102686267859224000000, 50] 0.000058113607504413816772205464778828177256611844221913
// -T(2853534237182741069uLL) / 49102686267859224000000uLL // j20 // error C2177: constant too big,
// so must use BOOST_MATH_TEST_VALUE(T, ) format in hope of using suffix Q for quad or decimal digits string for others.
//-T(0.000058113607504413816772205464778828177256611844221913L), // j20 N[2853534237182741069/49102686267859224000000, 50] 0.000058113607504413816772205464778828177256611844221913
- BOOST_MATH_TEST_VALUE(T, -0.000058113607504413816772205464778828177256611844221913) // j20 - last used by Fukushima
+ BOOST_MATH_BIG_CONSTANT(T, 113, -0.000058113607504413816772205464778828177256611844221913) // j20 - last used by Fukushima
// More terms don't seem to give any improvement (worse in fact) and are not use for many z values.
- //BOOST_MATH_TEST_VALUE(T, +0.000039076684867439051635395583044527492132109160553593), // j21
- //BOOST_MATH_TEST_VALUE(T, -0.000026338064747231098738584082718649443078703982217219), // j22
- //BOOST_MATH_TEST_VALUE(T, +0.000017790345805079585400736282075184540383274460464169), // j23
- //BOOST_MATH_TEST_VALUE(T, -0.000012040352739559976942274116578992585158113153190354), // j24
- //BOOST_MATH_TEST_VALUE(T, +8.1635319824966121713827512573558687050675701559448E-6), // j25
- //BOOST_MATH_TEST_VALUE(T, -5.5442032085673591366657251660804575198155559225316E-6) // j26
+ //BOOST_MATH_BIG_CONSTANT(T, +0.000039076684867439051635395583044527492132109160553593), // j21
+ //BOOST_MATH_BIG_CONSTANT(T, -0.000026338064747231098738584082718649443078703982217219), // j22
+ //BOOST_MATH_BIG_CONSTANT(T, +0.000017790345805079585400736282075184540383274460464169), // j23
+ //BOOST_MATH_BIG_CONSTANT(T, -0.000012040352739559976942274116578992585158113153190354), // j24
+ //BOOST_MATH_BIG_CONSTANT(T, +8.1635319824966121713827512573558687050675701559448E-6), // j25
+ //BOOST_MATH_BIG_CONSTANT(T, -5.5442032085673591366657251660804575198155559225316E-6) // j26
// -T(5.5442032085673591366657251660804575198155559225316E-6L) // j26
// 21 to 26 Added for long double.
}; // static const T q[]
@@ -296,27 +296,27 @@ T lambert_w_singularity_series(const T p)
//-T(0.0000581136075044138168L) // j20 N[2853534237182741069/49102686267859224000000, 50] 0.000058113607504413816772205464778828177256611844221913
// -T(2853534237182741069uLL) / 49102686267859224000000uLL // j20 // error C2177: constant too big,
- // so must use BOOST_MATH_TEST_VALUE(T, ) format in hope of using suffix Q for quad or decimal digits string for others.
+ // so must use BOOST_MATH_BIG_CONSTANT(T, ) format in hope of using suffix Q for quad or decimal digits string for others.
//-T(0.000058113607504413816772205464778828177256611844221913L), // j20 N[2853534237182741069/49102686267859224000000, 50] 0.000058113607504413816772205464778828177256611844221913